==> jc-1.4.0.tar.gz: soot/AnySubType.h <==
// public class soot.AnySubType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a03ebec6f6f11c23 soot_AnySubType
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_RefLikeType

#include "soot/RefLikeType.h"

#ifndef _JC_soot_AnySubType_H_
#define _JC_soot_AnySubType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_AnySubType$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_AnySubType$sub_refs	_jc_soot_AnySubType$sub_refs;
typedef struct _jc_soot_AnySubType$sub_nonrefs	_jc_soot_AnySubType$sub_nonrefs;
typedef struct _jc_soot_AnySubType$refs	_jc_soot_AnySubType$refs;
typedef struct _jc_soot_AnySubType$nonrefs	_jc_soot_AnySubType$nonrefs;
typedef struct _jc_soot_AnySubType$object	_jc_soot_AnySubType$object;

typedef const struct _jc_soot_AnySubType$vmethods	_jc_soot_AnySubType$vmethods;
typedef const struct _jc_soot_AnySubType$vtable	_jc_soot_AnySubType$vtable;
typedef const struct _jc_soot_AnySubType$vtype	_jc_soot_AnySubType$vtype;

// Constructors
extern void _jc_soot_AnySubType$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_soot_RefType$object *);

// Virtual methods
extern void _jc_soot_AnySubType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_object *);
extern struct _jc_soot_Type$object *_jc_soot_AnySubType$method$getArrayElementType$15d4b254b1d62067(_jc_env *, struct _jc_soot_AnySubType$object *);
extern struct _jc_soot_RefType$object *_jc_soot_AnySubType$method$getBase$86efda20570fe054(_jc_env *, struct _jc_soot_AnySubType$object *);
extern void _jc_soot_AnySubType$method$setBase$c61859c08ba6bbb3(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_soot_RefType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_AnySubType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_AnySubType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_AnySubType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_AnySubType$method_info$getArrayElementType$15d4b254b1d62067;
extern _jc_method _jc_soot_AnySubType$method_info$getBase$86efda20570fe054;
extern _jc_method _jc_soot_AnySubType$method_info$setBase$c61859c08ba6bbb3;
extern _jc_method _jc_soot_AnySubType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_AnySubType$object *_jc_soot_AnySubType$method$v$9f485d1e81f057a6(_jc_env *, struct _jc_soot_RefType$object *);

// Virtual methods structure
struct _jc_soot_AnySubType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_object *);
	struct _jc_soot_Type$object	*(*getArrayElementType$15d4b254b1d62067)(_jc_env *, struct _jc_soot_AnySubType$object *);
	struct _jc_soot_RefType$object	*(*getBase$86efda20570fe054)(_jc_env *, struct _jc_soot_AnySubType$object *);
	void	(*setBase$c61859c08ba6bbb3)(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_soot_RefType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_AnySubType$object *);
};

// Vtable
struct _jc_soot_AnySubType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_RefLikeType$vmethods	soot_RefLikeType;
	_jc_soot_AnySubType$vmethods	soot_AnySubType;
};

// Vtype
struct _jc_soot_AnySubType$vtype {
	_jc_type			type;
	_jc_soot_AnySubType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AnySubType$sub_refs {
	struct _jc_soot_RefType$object	*base;
};

// Reference instance fields (object)
struct _jc_soot_AnySubType$refs {
    _jc_soot_AnySubType$sub_refs	soot_AnySubType;
    _jc_soot_RefLikeType$sub_refs	soot_RefLikeType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AnySubType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AnySubType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_RefLikeType$sub_nonrefs	soot_RefLikeType;
    _jc_soot_AnySubType$sub_nonrefs	soot_AnySubType;
};

// Object instance structure
struct _jc_soot_AnySubType$object {
	_jc_soot_AnySubType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AnySubType$vtype	*vtype;
	_jc_soot_AnySubType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AnySubType$vtype _jc_soot_AnySubType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AnySubType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AnySubType$class_object;

#endif	/* _JC_soot_AnySubType_H_ */

==> jc-1.4.6.tar.gz: soot/AnySubType.h <==
// public class soot.AnySubType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a03ebec6f6f11c23 soot_AnySubType
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_RefLikeType

#include "soot/RefLikeType.h"

#ifndef _JC_soot_AnySubType_H_
#define _JC_soot_AnySubType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_AnySubType$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_AnySubType$sub_refs	_jc_soot_AnySubType$sub_refs;
typedef struct _jc_soot_AnySubType$sub_nonrefs	_jc_soot_AnySubType$sub_nonrefs;
typedef struct _jc_soot_AnySubType$refs	_jc_soot_AnySubType$refs;
typedef struct _jc_soot_AnySubType$nonrefs	_jc_soot_AnySubType$nonrefs;
typedef struct _jc_soot_AnySubType$object	_jc_soot_AnySubType$object;

typedef const struct _jc_soot_AnySubType$vmethods	_jc_soot_AnySubType$vmethods;
typedef const struct _jc_soot_AnySubType$vtable	_jc_soot_AnySubType$vtable;
typedef const struct _jc_soot_AnySubType$vtype	_jc_soot_AnySubType$vtype;

// Constructors
extern void _jc_soot_AnySubType$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_AnySubType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_AnySubType$method$getArrayElementType$15d4b254b1d62067(_jc_env *, struct _jc_soot_AnySubType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_RefType$object *_jc_soot_AnySubType$method$getBase$86efda20570fe054(_jc_env *, struct _jc_soot_AnySubType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_AnySubType$method$setBase$c61859c08ba6bbb3(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_AnySubType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_AnySubType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_AnySubType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_AnySubType$method_info$getArrayElementType$15d4b254b1d62067;
extern _jc_method _jc_soot_AnySubType$method_info$getBase$86efda20570fe054;
extern _jc_method _jc_soot_AnySubType$method_info$setBase$c61859c08ba6bbb3;
extern _jc_method _jc_soot_AnySubType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_AnySubType$object *_jc_soot_AnySubType$method$v$9f485d1e81f057a6(_jc_env *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_AnySubType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getArrayElementType$15d4b254b1d62067)(_jc_env *, struct _jc_soot_AnySubType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_RefType$object	*(*getBase$86efda20570fe054)(_jc_env *, struct _jc_soot_AnySubType$object *) _JC_JCNI_ATTR;
	void	(*setBase$c61859c08ba6bbb3)(_jc_env *, struct _jc_soot_AnySubType$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_AnySubType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_AnySubType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_RefLikeType$vmethods	soot_RefLikeType;
	_jc_soot_AnySubType$vmethods	soot_AnySubType;
};

// Vtype
struct _jc_soot_AnySubType$vtype {
	_jc_type			type;
	_jc_soot_AnySubType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AnySubType$sub_refs {
	struct _jc_soot_RefType$object	*base;
};

// Reference instance fields (object)
struct _jc_soot_AnySubType$refs {
    _jc_soot_AnySubType$sub_refs	soot_AnySubType;
    _jc_soot_RefLikeType$sub_refs	soot_RefLikeType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AnySubType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AnySubType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_RefLikeType$sub_nonrefs	soot_RefLikeType;
    _jc_soot_AnySubType$sub_nonrefs	soot_AnySubType;
};

// Object instance structure
struct _jc_soot_AnySubType$object {
	_jc_soot_AnySubType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AnySubType$vtype	*vtype;
	_jc_soot_AnySubType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AnySubType$vtype _jc_soot_AnySubType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AnySubType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AnySubType$class_object;

#endif	/* _JC_soot_AnySubType_H_ */
